Test of Tutorials!
^^^^^^^^^^^^^^^^^^
This is a simple test script to check that all is working as expected. Below should be an image of an empty axis... if not, then Houston we have a problem 

.. code-block:: python
   :linenos:

   import numpy as np
   import matplotlib.pyplot as plt
   
   fig,ax = plt.subplots()
   fig.savefig('figure0.png',format='png'),r'docs/Tutorials/TEST.png'),format='png',dpi=300)
   

Showcasing functionality
------------------------
This should be the showcasing...An example is shown in the above code generating the figure below:
 .. figure:: TEST.png
  :width: 50%
  :align: center

